@@ -68,11 +68,10 @@
 #' # look at the data frame
 #' as.data.frame(result)
 #'
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
 #' \donttest{
 #' # plot
-#' if (require("see")) {
-#'   plot(result, show_dots = TRUE)
-#' }
+#' plot(result, show_dots = TRUE)
 #' }
 #'
 #' @export
@@ -86,7 +85,6 @@ binned_residuals <- function(model,
                              iterations = 1000,
                              verbose = TRUE,
                              ...) {
-  # match arguments
   ci_type <- match.arg(ci_type)
   residuals <- match.arg(residuals)
 
@@ -143,17 +141,22 @@ binned_residuals <- function(model,
     n <- length(items)
     sdev <- stats::sd(y[items], na.rm = TRUE)
 
-    conf_int <- switch(ci_type,
-      gaussian = stats::qnorm(c((1 - ci) / 2, (1 + ci) / 2), mean = ybar, sd = sdev / sqrt(n)),
-      exact = {
-        out <- stats::binom.test(sum(y0[items]), n)$conf.int
-        # center CIs around point estimate
-        out <- out - (min(out) - ybar) - (diff(out) / 2)
-        out
-      },
-      boot = .boot_binned_ci(y[items], ci, iterations)
-    )
-    names(conf_int) <- c("CI_low", "CI_high")
+    # sanity check - do we have any data in our bin?
+    if (n == 0) {
+      conf_int <- stats::setNames(c(NA, NA), c("CI_low", "CI_high"))
+    } else {
+      conf_int <- switch(ci_type,
+        gaussian = stats::qnorm(c((1 - ci) / 2, (1 + ci) / 2), mean = ybar, sd = sdev / sqrt(n)),
+        exact = {
+          out <- stats::binom.test(sum(y0[items]), n)$conf.int
+          # center CIs around point estimate
+          out <- out - (min(out) - ybar) - (diff(out) / 2)
+          out
+        },
+        boot = .boot_binned_ci(y[items], ci, iterations)
+      )
+      names(conf_int) <- c("CI_low", "CI_high")
+    }
 
     d0 <- data.frame(
       xbar = xbar,
