@@ -26,17 +26,15 @@
 #' check_homogeneity(model)
 #'
 #' # plot results
-#' if (require("see")) {
-#'   result <- check_homogeneity(model)
-#'   plot(result)
-#' }
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
+#' result <- check_homogeneity(model)
+#' plot(result)
 #' @export
 check_homogeneity <- function(x, method = c("bartlett", "fligner", "levene", "auto"), ...) {
   UseMethod("check_homogeneity")
 }
 
 
-
 # default -------------------------
 
 #' @export
@@ -70,14 +68,14 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
     )
 
     if (is.null(check)) {
-      insight::print_color("'check_homogeneity()' cannot perform check for normality. Please specify the 'method'-argument for the test of equal variances.\n", "red")
+      insight::print_color("'check_homogeneity()' cannot perform check for normality. Please specify the 'method'-argument for the test of equal variances.\n", "red") # nolint
       return(NULL)
     }
 
     method <- ifelse(check < 0.05, "fligner", "bartlett")
   }
 
-  if (method == "fligner") {
+  if (method == "fligner") { # nolint
     r <- stats::fligner.test(f, data = insight::get_data(x, verbose = FALSE))
     p.val <- r$p.value
   } else if (method == "bartlett") {
@@ -105,7 +103,6 @@ check_homogeneity.default <- function(x, method = c("bartlett", "fligner", "leve
 }
 
 
-
 # methods -----------------------
 
 #' @export
@@ -130,7 +127,6 @@ plot.check_homogeneity <- function(x, ...) {
 }
 
 
-
 # other classes -----------------------------
 
 #' @rdname check_homogeneity
@@ -157,7 +153,7 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
 
   if (any(is_covar)) {
     insight::format_alert(
-      "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only."
+      "Levene's test is not appropriate with quantitative explanatory variables. Testing assumption of homogeneity among factor groups only." # nolint
     )
     # ## TODO maybe add as option?
     # warning("Testing assumption of homogeneity on residualzied data among factor groups only.", call. = FALSE)
@@ -165,7 +161,7 @@ check_homogeneity.afex_aov <- function(x, method = "levene", ...) {
     between <- between[!is_covar]
   }
 
-  form <- stats::formula(paste0(dv, "~", paste0(between, collapse = "*")))
+  form <- stats::formula(paste0(dv, "~", paste(between, collapse = "*")))
   test <- car::leveneTest(form, ag_data, center = mean, ...)
 
   p.val <- test[1, "Pr(>F)"]
