@@ -12,7 +12,8 @@
 #'   by at least half of the methods). See the **Details** section below
 #'   for a description of the methods.
 #'
-#' @param x A model or a data.frame object.
+#' @param x A model, a data.frame, a `performance_simres` [`simulate_residuals()`]
+#' or a `DHARMa` object.
 #' @param method The outlier detection method(s). Can be `"all"` or some of
 #'   `"cook"`, `"pareto"`, `"zscore"`, `"zscore_robust"`, `"iqr"`, `"ci"`, `"eti"`,
 #'   `"hdi"`, `"bci"`, `"mahalanobis"`, `"mahalanobis_robust"`, `"mcd"`, `"ics"`,
@@ -23,9 +24,19 @@
 #'   'Details'). If a numeric value is given, it will be used as the threshold
 #'   for any of the method run.
 #' @param ID Optional, to report an ID column along with the row number.
+#' @param type Type of method to test for outliers. Can be one of `"default"`,
+#' `"binomial"` or `"bootstrap"`. Only applies when `x` is an object returned
+#' by `simulate_residuals()` or of class `DHARMa`. See 'Details' in
+#' `?DHARMa::testOutliers` for a detailed description of the types.
+#' @param verbose Toggle warnings.
 #' @param ... When `method = "ics"`, further arguments in `...` are passed
 #' down to [ICSOutlier::ics.outlier()]. When `method = "mahalanobis"`,
-#' they are  passed down to [stats::mahalanobis()].
+#' they are  passed down to [stats::mahalanobis()]. `percentage_central` can
+#' be specified when `method = "mcd"`. For objects of class `performance_simres`
+#' or `DHARMa`, further arguments are passed down to `DHARMa::testOutliers()`.
+#'
+#' @inheritParams check_zeroinflation
+#' @inheritParams simulate_residuals
 #'
 #' @return A logical vector of the detected outliers with a nice printing
 #'   method: a check (message) on whether outliers were detected or not. The
@@ -36,6 +47,8 @@
 #'
 #' @family functions to check model assumptions and and assess model quality
 #'
+#' @seealso [`see::plot.see_check_outliers()`] for options to customize the plot.
+#'
 #' @note There is also a
 #'   [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
 #'   implemented in the
@@ -96,7 +109,7 @@
 #'  default threshold to classify outliers is 1.959 (`threshold = list("zscore" = 1.959)`),
 #'  corresponding to the 2.5% (`qnorm(0.975)`) most extreme observations
 #'  (assuming the data is normally distributed). Importantly, the Z-score
-#'  method is univariate: it is computed column by column. If a dataframe is
+#'  method is univariate: it is computed column by column. If a data frame is
 #'  passed, the Z-score is calculated for each variable separately, and the
 #'  maximum (absolute) Z-score is kept for each observations. Thus, all
 #'  observations that are extreme on at least one variable might be detected
@@ -160,6 +173,9 @@
 #' the data (by default, 66\%), before computing the Mahalanobis Distance. This
 #' is deemed to be a more robust method of identifying and removing outliers
 #' than regular Mahalanobis distance.
+#' This method has a `percentage_central` argument that allows specifying
+#' the breakdown point (0.75, the default, is recommended by Leys et al. 2018,
+#' but a commonly used alternative is 0.50).
 #'
 #'  - **Invariant Coordinate Selection (ICS)**:
 #'  The outlier are detected using ICS, which by default uses an alpha threshold
@@ -182,7 +198,8 @@
 #'  extreme values), this algorithm functions in a different manner and won't
 #'  always detect outliers. Note that `method = "optics"` requires the
 #'  **dbscan** package to be installed, and that it takes some time to compute
-#'  the results.
+#'  the results. Additionally, the `optics_xi` (default to 0.05) is passed to
+#'  the [dbscan::extractXi()] function to further refine the cluster selection.
 #'
 #'  - **Local Outlier Factor**:
 #'  Based on a K nearest neighbors algorithm, LOF compares the local density of
@@ -195,6 +212,17 @@
 #'  observations located at `qnorm(1-0.025) * SD)` of the log-transformed
 #'  LOF distance. Requires the **dbscan** package.
 #'
+#' @section Methods for simulated residuals:
+#'
+#' The approach for detecting outliers based on simulated residuals differs
+#' from the traditional methods and may not be detecting outliers as expected.
+#' Literally, this approach compares observed to simulated values. However, we
+#' do not know the deviation of the observed data to the model expectation, and
+#' thus, the term "outlier" should be taken with a grain of salt. It refers to
+#' "simulation outliers". Basically, the comparison tests whether on observed
+#' data point is outside the simulated range. It is strongly recommended to read
+#' the related documentations in the **DHARMa** package, e.g. `?DHARMa::testOutliers`.
+#'
 #' @section Threshold specification:
 #'
 #' Default thresholds are currently specified as follows:
@@ -215,6 +243,7 @@
 #'   mcd = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
 #'   ics = 0.001,
 #'   optics = 2 * ncol(x),
+#'   optics_xi = 0.05,
 #'   lof = 0.001
 #' )
 #' ```
@@ -228,29 +257,29 @@
 #' @references
 #' - Archimbaud, A., Nordhausen, K., and Ruiz-Gazen, A. (2018). ICS for
 #' multivariate outlier detection with application to quality control.
-#' Computational Statistics and Data Analysis, 128, 184-199.
+#' *Computational Statistics and Data Analysis*, *128*, 184-199.
 #' \doi{10.1016/j.csda.2018.06.011}
 #'
 #' - Gnanadesikan, R., and Kettenring, J. R. (1972). Robust estimates, residuals,
-#' and outlier detection with multiresponse data. Biometrics, 81-124.
+#' and outlier detection with multiresponse data. *Biometrics*, 81-124.
 #'
 #' - Bollen, K. A., and Jackman, R. W. (1985). Regression diagnostics: An
-#' expository treatment of outliers and influential cases. Sociological Methods
-#' and Research, 13(4), 510-542.
+#' expository treatment of outliers and influential cases. *Sociological Methods
+#' and Research*, *13*(4), 510-542.
 #'
 #' - Cabana, E., Lillo, R. E., and Laniado, H. (2019). Multivariate outlier
 #' detection based on a robust Mahalanobis distance with shrinkage estimators.
 #' arXiv preprint arXiv:1904.02596.
 #'
 #' - Cook, R. D. (1977). Detection of influential observation in linear
-#' regression. Technometrics, 19(1), 15-18.
+#' regression. *Technometrics*, *19*(1), 15-18.
 #'
 #' - Iglewicz, B., and Hoaglin, D. C. (1993). How to detect and handle outliers
 #' (Vol. 16). Asq Press.
 #'
 #' - Leys, C., Klein, O., Dominicy, Y., and Ley, C. (2018). Detecting
-#' multivariate outliers: Use a robust variant of Mahalanobis distance. Journal
-#' of Experimental Social Psychology, 74, 150-156.
+#' multivariate outliers: Use a robust variant of Mahalanobis distance. *Journal
+#' of Experimental Social Psychology*, 74, 150-156.
 #'
 #' - Liu, F. T., Ting, K. M., and Zhou, Z. H. (2008, December). Isolation forest.
 #' In 2008 Eighth IEEE International Conference on Data Mining (pp. 413-422).
@@ -258,16 +287,17 @@
 #'
 #' - Lüdecke, D., Ben-Shachar, M. S., Patil, I., Waggoner, P., and Makowski, D.
 #' (2021). performance: An R package for assessment, comparison and testing of
-#' statistical models. Journal of Open Source Software, 6(60), 3139.
+#' statistical models. *Journal of Open Source Software*, *6*(60), 3139.
 #' \doi{10.21105/joss.03139}
 #'
 #' - Thériault, R., Ben-Shachar, M. S., Patil, I., Lüdecke, D., Wiernik, B. M.,
 #' and Makowski, D. (2023). Check your outliers! An introduction to identifying
-#' statistical outliers in R with easystats. \doi{10.31234/osf.io/bu6nt}
+#' statistical outliers in R with easystats. *Behavior Research Methods*, 1-11.
+#' \doi{10.3758/s13428-024-02356-w}
 #'
 #' - Rousseeuw, P. J., and Van Zomeren, B. C. (1990). Unmasking multivariate
-#' outliers and leverage points. Journal of the American Statistical
-#' association, 85(411), 633-639.
+#' outliers and leverage points. *Journal of the American Statistical
+#' association*, *85*(411), 633-639.
 #'
 #' @examples
 #' data <- mtcars # Size nrow(data) = 32
@@ -276,14 +306,14 @@
 #' outliers_list <- check_outliers(data$mpg) # Find outliers
 #' outliers_list # Show the row index of the outliers
 #' as.numeric(outliers_list) # The object is a binary vector...
-#' filtered_data <- data[!outliers_list, ] # And can be used to filter a dataframe
+#' filtered_data <- data[!outliers_list, ] # And can be used to filter a data frame
 #' nrow(filtered_data) # New size, 28 (4 outliers removed)
 #'
 #' # Find all observations beyond +/- 2 SD
 #' check_outliers(data$mpg, method = "zscore", threshold = 2)
 #'
 #' # For dataframes ------------------------------------------------------
-#' check_outliers(data) # It works the same way on dataframes
+#' check_outliers(data) # It works the same way on data frames
 #'
 #' # You can also use multiple methods at once
 #' outliers_list <- check_outliers(data, method = c(
@@ -304,11 +334,12 @@
 #' # We can run the function stratified by groups using `{datawizard}` package:
 #' group_iris <- datawizard::data_group(iris, "Species")
 #' check_outliers(group_iris)
-#'
-#' @examplesIf require("see") && require("bigutilsr") && require("loo") && require("MASS") && require("ICSOutlier") && require("ICS") && require("dbscan")
+#' # nolint start
+#' @examplesIf all(insight::check_if_installed(c("bigutilsr", "MASS", "ICSOutlier", "ICS", "dbscan", "loo", "see"), quietly = TRUE))
+#' # nolint end
 #' \donttest{
 #' # You can also run all the methods
-#' check_outliers(data, method = "all")
+#' check_outliers(data, method = "all", verbose = FALSE)
 #'
 #' # For statistical models ---------------------------------------------
 #' # select only mpg and disp (continuous)
@@ -344,57 +375,63 @@ check_outliers.default <- function(x,
                                    method = c("cook", "pareto"),
                                    threshold = NULL,
                                    ID = NULL,
+                                   verbose = TRUE,
                                    ...) {
   # Check args
   if (all(method == "all")) {
     method <- c(
-      "zscore_robust",
-      "iqr",
-      "ci",
-      "cook",
-      "pareto",
-      "mahalanobis",
-      "mahalanobis_robust",
-      "mcd",
-      "ics",
-      "optics",
-      "lof"
+      "zscore_robust", "iqr", "ci", "cook", "pareto", "mahalanobis",
+      "mahalanobis_robust", "mcd", "ics", "optics", "lof"
     )
   }
 
   method <- match.arg(
     method,
     c(
-      "zscore",
-      "zscore_robust",
-      "iqr",
-      "ci",
-      "hdi",
-      "eti",
-      "bci",
-      "cook",
-      "pareto",
-      "mahalanobis",
-      "mahalanobis_robust",
-      "mcd",
-      "ics",
-      "optics",
-      "lof"
+      "zscore", "zscore_robust", "iqr", "ci", "hdi", "eti", "bci", "cook",
+      "pareto", "mahalanobis", "mahalanobis_robust", "mcd", "ics", "optics", "lof"
     ),
     several.ok = TRUE
   )
 
-  # Get data
-  data <- insight::get_data(x, verbose = FALSE)
+  # Get model information
+  m_info <- insight::model_info(x)
 
-  # Remove non-numerics
-  data <- datawizard::data_select(data, select = is.numeric)
+  # Get data
+  my_data <- insight::get_data(x, verbose = FALSE)
+
+  # sanity check for date, POSIXt and difftime variables
+  if (any(vapply(my_data, inherits, FUN.VALUE = logical(1), what = c("Date", "POSIXt", "difftime"))) && verbose) {
+    insight::format_alert(
+      paste(
+        "Date variables are not supported for outliers detection. These will be ignored.",
+        "Make sure any date variables are converted to numeric or factor {.b before} fitting the model."
+      )
+    )
+  }
+
+  # Remove non-numerics, but in case of binomial, only check predictors
+  if (m_info$is_binomial) {
+    model_predictors <- unique(insight::find_predictors(x, flatten = TRUE))
+  } else {
+    model_predictors <- colnames(my_data)
+  }
+  my_data <- datawizard::data_select(
+    my_data[model_predictors],
+    select = is.numeric,
+    verbose = FALSE
+  )
+
+  # check if any data left
+  if (is.null(my_data) || ncol(my_data) == 0) {
+    insight::format_error("No numeric variables found. No data to check for outliers.")
+  }
 
   # Thresholds
   if (is.null(threshold)) {
-    thresholds <- .check_outliers_thresholds(data)
+    thresholds <- .check_outliers_thresholds(my_data)
   } else if (is.list(threshold)) {
-    thresholds <- .check_outliers_thresholds(data)
+    thresholds <- .check_outliers_thresholds(my_data)
     thresholds[names(threshold)] <- threshold[names(threshold)]
   } else {
     insight::format_error(
@@ -405,31 +442,31 @@ check_outliers.default <- function(x,
     )
   }
 
-  if (!missing(ID)) {
+  if (!missing(ID) && verbose) {
     insight::format_warning(paste0("ID argument not supported for model objects of class `", class(x)[1], "`."))
   }
 
   # Others
   if (all(method %in% c("cook", "pareto"))) {
-    df <- data.frame(Row = seq_len(nrow(as.data.frame(data))))
+    my_df <- data.frame(Row = seq_len(nrow(as.data.frame(my_data))))
     outlier_count <- list()
     outlier_var <- list()
   } else {
-    out <- check_outliers(data, method, threshold)
+    out <- check_outliers(my_data, method, threshold)
     outlier_var <- attributes(out)$outlier_var
     outlier_count <- attributes(out)$outlier_count
-    df <- attributes(out)$data
-    df <- df[!names(df) == "Outlier"]
+    my_df <- attributes(out)$data
+    my_df <- my_df[names(my_df) != "Outlier"]
   }
 
   # Cook
-  if ("cook" %in% method && !insight::model_info(x)$is_bayesian && !inherits(x, "bife")) {
+  if ("cook" %in% method && !m_info$is_bayesian && !inherits(x, "bife")) {
     data_cook <- .check_outliers_cook(
       x,
       threshold = thresholds$cook
     )$data_cook
 
-    df <- datawizard::data_merge(list(df, data_cook),
+    my_df <- datawizard::data_merge(list(my_df, data_cook),
       join = "full",
       by = "Row"
     )
@@ -459,17 +496,17 @@ check_outliers.default <- function(x,
       )
     }
   } else {
-    method <- method[!(method == "cook")]
+    method <- method[method != "cook"]
   }
 
   # Pareto
-  if ("pareto" %in% method && insight::model_info(x)$is_bayesian) {
+  if ("pareto" %in% method && m_info$is_bayesian) {
     data_pareto <- .check_outliers_pareto(
       x,
       threshold = thresholds$pareto
     )$data_pareto
 
-    df <- datawizard::data_merge(list(df, data_pareto),
+    my_df <- datawizard::data_merge(list(my_df, data_pareto),
       join = "full",
       by = "Row"
     )
@@ -499,7 +536,7 @@ check_outliers.default <- function(x,
       )
     }
   } else {
-    method <- method[!(method == "pareto")]
+    method <- method[method != "pareto"]
   }
 
   outlier_count$all <- datawizard::convert_na_to(outlier_count$all,
@@ -531,21 +568,21 @@ check_outliers.default <- function(x,
   thresholds <- thresholds[names(thresholds) %in% method]
 
   # Composite outlier score
-  df$Outlier <- rowMeans(df[grepl("Outlier_", names(df), fixed = TRUE)])
-  df <- df[c(names(df)[names(df) != "Outlier"], "Outlier")]
+  my_df$Outlier <- rowMeans(my_df[grepl("Outlier_", names(my_df), fixed = TRUE)])
+  my_df <- my_df[c(names(my_df)[names(my_df) != "Outlier"], "Outlier")]
 
   # Out
-  outlier <- df$Outlier > 0.5
+  outlier <- my_df$Outlier > 0.5
 
   # Attributes
   class(outlier) <- c("check_outliers", "see_check_outliers", class(outlier))
-  attr(outlier, "data") <- df
+  attr(outlier, "data") <- my_df
   attr(outlier, "threshold") <- thresholds
   attr(outlier, "method") <- method
   attr(outlier, "text_size") <- 3
-  attr(outlier, "influential_obs") <- .influential_obs(x)
+  attr(outlier, "influential_obs") <- .safe(.model_diagnostic_outlier(x, threshold = unlist(thresholds))) # nolint
   attr(outlier, "variables") <- "(Whole model)"
-  attr(outlier, "raw_data") <- data
+  attr(outlier, "raw_data") <- my_data
   attr(outlier, "outlier_var") <- outlier_var
   attr(outlier, "outlier_count") <- outlier_count
 
@@ -553,7 +590,6 @@ check_outliers.default <- function(x,
 }
 
 
-
 # Methods -----------------------------------------------------------------
 
 #' @export
@@ -562,7 +598,7 @@ as.data.frame.check_outliers <- function(x, ...) {
 }
 
 #' @export
-as.numeric.check_outliers <- function(x, ...) {
+as.double.check_outliers <- function(x, ...) {
   attributes(x)$data$Outlier
 }
 
@@ -764,6 +800,27 @@ plot.check_outliers <- function(x, ...) {
   NextMethod()
 }
 
+#' @export
+print.check_outliers_simres <- function(x, digits = 2, ...) {
+  result <- paste0(
+    insight::format_value(100 * x$Expected, digits = digits, ...),
+    "%, ",
+    insight::format_ci(100 * x$CI_low, 100 * x$CI_high, digits = digits, ...)
+  )
+  insight::print_color("# Outliers detection\n\n", "blue")
+  cat(sprintf("  Proportion of observed outliers: %.*f%%\n", digits, 100 * x$Coefficient))
+  cat(sprintf("  Proportion of expected outliers: %s\n\n", result))
+
+  p_string <- paste0(" (", insight::format_p(x$p_value), ")")
+
+  if (x$p_value < 0.05) {
+    message("Outliers were detected", p_string, ".")
+  } else {
+    message("No outliers were detected", p_string, ".")
+  }
+
+  invisible(x)
+}
 
 
 # other classes -------------------------
@@ -784,7 +841,6 @@ check_outliers.numeric <- function(x,
 }
 
 
-
 #' @rdname check_outliers
 #' @export
 check_outliers.data.frame <- function(x,
@@ -798,7 +854,7 @@ check_outliers.data.frame <- function(x,
   )
 
   # Remove non-numerics
-  data <- x
+  my_data <- x
   x <- x[, vapply(x, is.numeric, logical(1)), drop = FALSE]
 
   # Check args
@@ -824,6 +880,13 @@ check_outliers.data.frame <- function(x,
   } else if (is.numeric(threshold)) {
     thresholds <- .check_outliers_thresholds(x)
     thresholds <- lapply(thresholds, function(x) threshold)
+    # need to fix this manually - "optics" automatically includes method
+    # "optics_xi", which is allowed to range between 0 and 1 - since values
+    # for "optics" can be > 1, it might overwrite "optics_xi" with an invalid
+    # value...
+    if (thresholds$optics_xi > 1) {
+      thresholds$optics_xi <- 0.05
+    }
   } else {
     insight::format_error(
       paste(
@@ -833,7 +896,13 @@ check_outliers.data.frame <- function(x,
     )
   }
 
-  thresholds <- thresholds[names(thresholds) %in% method]
+  # Keep only relevant threshold
+  valid <- method
+  if ("optics" %in% valid) {
+    valid <- c(valid, "optics_xi")
+    method <- c(method, "optics_xi")
+  }
+  thresholds <- thresholds[names(thresholds) %in% valid]
 
   out.meta <- .check_outliers.data.frame_method(x, method, thresholds, ID, ID.names, ...)
   out <- out.meta$out
@@ -841,20 +910,20 @@ check_outliers.data.frame <- function(x,
   outlier_var <- out.meta$outlier_var
 
   # Combine outlier data
-  df <- out[vapply(out, is.data.frame, logical(1))]
-  if (length(df) > 1 && !is.null(ID)) {
-    df <- datawizard::data_merge(df, by = c("Row", ID))
-  } else if (length(df) > 1) {
-    df <- datawizard::data_merge(df, by = "Row")
+  my_df <- out[vapply(out, is.data.frame, logical(1))]
+  if (length(my_df) > 1 && !is.null(ID)) {
+    my_df <- datawizard::data_merge(my_df, by = c("Row", ID))
+  } else if (length(my_df) > 1) {
+    my_df <- datawizard::data_merge(my_df, by = "Row")
   } else {
-    df <- df[[1]]
+    my_df <- my_df[[1]]
   }
 
   # Composite outlier score
-  df$Outlier <- rowMeans(df[grepl("Outlier_", names(df), fixed = TRUE)])
+  my_df$Outlier <- rowMeans(my_df[grepl("Outlier_", names(my_df), fixed = TRUE)])
 
   # Out
-  outlier <- df$Outlier > 0.5
+  outlier <- my_df$Outlier > 0.5
 
   # Combine outlier frequency table
   if (length(outlier_count) > 1 && !is.null(ID)) {
@@ -881,7 +950,7 @@ check_outliers.data.frame <- function(x,
   outlier_count <- lapply(outlier_count, function(x) {
     num.df <- x[!names(x) %in% c("Row", ID)]
     if (isTRUE(nrow(num.df) >= 1)) {
-      num.df <- datawizard::change_code(
+      num.df <- datawizard::recode_values(
         num.df,
         recode = list(`2` = "(Multivariate)")
       )
@@ -896,12 +965,12 @@ check_outliers.data.frame <- function(x,
 
   # Attributes
   class(outlier) <- c("check_outliers", "see_check_outliers", class(outlier))
-  attr(outlier, "data") <- df
+  attr(outlier, "data") <- my_df
   attr(outlier, "threshold") <- thresholds
   attr(outlier, "method") <- method
   attr(outlier, "text_size") <- 3
   attr(outlier, "variables") <- names(x)
-  attr(outlier, "raw_data") <- data
+  attr(outlier, "raw_data") <- my_data
   attr(outlier, "outlier_var") <- outlier_var
   attr(outlier, "outlier_count") <- outlier_count
   outlier
@@ -914,7 +983,7 @@ check_outliers.data.frame <- function(x,
     outlier.list <- lapply(outlier.list, function(x) {
       x[x[[Outlier_method]] >= 0.5, ]
     })
-    outlier.list <- outlier.list[lapply(outlier.list, nrow) > 0]
+    outlier.list <- outlier.list[vapply(outlier.list, nrow, numeric(1)) > 0]
     outlier.list <- lapply(outlier.list, datawizard::data_remove,
       Outlier_method,
       as_data_frame = TRUE
@@ -1098,8 +1167,8 @@ check_outliers.data.frame <- function(x,
     out <- c(out, .check_outliers_mcd(
       x,
       threshold = thresholds$mcd,
-      percentage_central = 0.66,
-      ID.names = ID.names
+      ID.names = ID.names,
+      ...
     ))
 
     count.table <- datawizard::data_filter(
@@ -1150,7 +1219,8 @@ check_outliers.data.frame <- function(x,
     out <- c(out, .check_outliers_optics(
       x,
       threshold = thresholds$optics,
-      ID.names = ID.names
+      ID.names = ID.names,
+      xi = thresholds$optics_xi
     ))
 
     count.table <- datawizard::data_filter(
@@ -1217,7 +1287,7 @@ check_outliers.grouped_df <- function(x,
   }
 
   # Initialize elements
-  data <- data.frame()
+  my_data <- data.frame()
   out <- NULL
   thresholds <- list()
   outlier_var <- list()
@@ -1226,24 +1296,24 @@ check_outliers.grouped_df <- function(x,
   # Loop through groups
   for (i in seq_along(grps)) {
     rows <- grps[[i]]
-    subset <- check_outliers(
+    outliers_subset <- check_outliers(
       as.data.frame(x[rows, ]),
       method = method,
       threshold = threshold,
       ID = ID,
       ...
     )
-    data <- rbind(data, as.data.frame(subset))
-    out <- c(out, subset)
-    thresholds[[paste0("group_", i)]] <- attributes(subset)$threshold
+    my_data <- rbind(my_data, as.data.frame(outliers_subset))
+    out <- c(out, outliers_subset)
+    thresholds[[paste0("group_", i)]] <- attributes(outliers_subset)$threshold
     outlier_var[[i]] <- lapply(
-      attributes(subset)$outlier_var, lapply, function(y) {
+      attributes(outliers_subset)$outlier_var, lapply, function(y) {
         y$Row <- rows[which(seq_along(rows) %in% y$Row)]
         y
       }
     )
     outlier_count[[i]] <- lapply(
-      attributes(subset)$outlier_count, function(y) {
+      attributes(outliers_subset)$outlier_count, function(y) {
         y$Row <- rows[which(seq_along(rows) %in% y$Row)]
         y
       }
@@ -1264,16 +1334,16 @@ check_outliers.grouped_df <- function(x,
     info$groups$.rows[[x]] <- as.data.frame(info$groups$.rows[[x]])
   })
 
-  data[names(info$groups)[1]] <- do.call(rbind, groups)
-  data <- datawizard::data_relocate(
-    data,
+  my_data[names(info$groups)[1]] <- do.call(rbind, groups)
+  my_data <- datawizard::data_relocate(
+    my_data,
     select = names(info$groups)[1],
     after = "Row"
   )
-  data$Row <- seq_len(nrow(data))
+  my_data$Row <- seq_len(nrow(my_data))
 
   class(out) <- c("check_outliers", "see_check_outliers", class(out))
-  attr(out, "data") <- data
+  attr(out, "data") <- my_data
   attr(out, "method") <- method
   attr(out, "threshold") <- thresholds[[1]]
   attr(out, "text_size") <- 3
@@ -1304,7 +1374,6 @@ check_outliers.BFBayesFactor <- function(x,
 }
 
 
-
 #' @export
 check_outliers.gls <- function(x,
                                method = "pareto",
@@ -1417,6 +1486,29 @@ check_outliers.meta <- check_outliers.metagen
 check_outliers.metabin <- check_outliers.metagen
 
 
+#' @rdname check_outliers
+#' @export
+check_outliers.performance_simres <- function(x, type = "default", iterations = 100, alternative = "two.sided", ...) {
+  type <- match.arg(type, c("default", "binomial", "bootstrap"))
+  alternative <- match.arg(alternative, c("two.sided", "greater", "less"))
+
+  insight::check_if_installed("DHARMa")
+  result <- DHARMa::testOutliers(x, type = type, nBoot = iterations, alternative = alternative, plot = FALSE, ...)
+
+  outlier <- list(
+    Coefficient = as.vector(result$estimate),
+    Expected = as.numeric(gsub("(.*)\\(expected: (\\d.*)\\)", "\\2", names(result$estimate))),
+    CI_low = result$conf.int[1],
+    CI_high = result$conf.int[2],
+    p_value = result$p.value
+  )
+  class(outlier) <- c("check_outliers_simres", class(outlier))
+  outlier
+}
+
+#' @export
+check_outliers.DHARMa <- check_outliers.performance_simres
+
 
 # Thresholds --------------------------------------------------------------
 
@@ -1425,43 +1517,27 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 .check_outliers_thresholds_nowarn <- function(x) {
-  zscore <- stats::qnorm(p = 1 - 0.001 / 2)
-  zscore_robust <- stats::qnorm(p = 1 - 0.001 / 2)
-  iqr <- 1.7
-  ci <- 1 - 0.001
-  eti <- 1 - 0.001
-  hdi <- 1 - 0.001
-  bci <- 1 - 0.001
-  cook <- stats::qf(0.5, ncol(x), nrow(x) - ncol(x))
-  pareto <- 0.7
-  mahalanobis <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  mahalanobis_robust <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  mcd <- stats::qchisq(p = 1 - 0.001, df = ncol(x))
-  ics <- 0.001
-  optics <- 2 * ncol(x)
-  lof <- 0.001
-
   list(
-    zscore = zscore,
-    zscore_robust = zscore_robust,
-    iqr = iqr,
-    ci = ci,
-    hdi = hdi,
-    eti = eti,
-    bci = bci,
-    cook = cook,
-    pareto = pareto,
-    mahalanobis = mahalanobis,
-    mahalanobis_robust = mahalanobis_robust,
-    mcd = mcd,
-    ics = ics,
-    optics = optics,
-    lof = lof
+    zscore = stats::qnorm(p = 1 - 0.001 / 2),
+    zscore_robust = stats::qnorm(p = 1 - 0.001 / 2),
+    iqr = 1.7,
+    ci = 1 - 0.001,
+    hdi = 1 - 0.001,
+    eti = 1 - 0.001,
+    bci = 1 - 0.001,
+    cook = stats::qf(0.5, ncol(x), nrow(x) - ncol(x)),
+    pareto = 0.7,
+    mahalanobis = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    mahalanobis_robust = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    mcd = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
+    ics = 0.001,
+    optics = 2 * ncol(x),
+    optics_xi = 0.05,
+    lof = 0.001
   )
 }
 
 
-
 # utilities --------------------
 
 .check_outliers_zscore <- function(x,
@@ -1520,7 +1596,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_iqr <- function(x,
                                 threshold = 1.7,
                                 method = "tukey",
@@ -1572,7 +1647,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_ci <- function(x,
                                threshold = 1 - 0.001,
                                method = "ci",
@@ -1623,7 +1697,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_cook <- function(x,
                                  threshold = NULL,
                                  ID.names = NULL) {
@@ -1642,7 +1715,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_pareto <- function(x, threshold = 0.7) {
   insight::check_if_installed("loo")
 
@@ -1662,7 +1734,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_mahalanobis <- function(x,
                                         threshold = stats::qchisq(
                                           p = 1 - 0.001, df = ncol(x)
@@ -1692,7 +1763,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 # Bigutils not yet fully available on CRAN
 .check_outliers_mahalanobis_robust <- function(x,
                                                threshold = stats::qchisq(
@@ -1723,17 +1793,33 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_mcd <- function(x,
                                 threshold = stats::qchisq(p = 1 - 0.001, df = ncol(x)),
-                                percentage_central = 0.50,
-                                ID.names = NULL) {
+                                percentage_central = 0.75,
+                                ID.names = NULL,
+                                verbose = TRUE,
+                                ...) {
   out <- data.frame(Row = seq_len(nrow(x)))
 
   if (!is.null(ID.names)) {
     out <- cbind(out, ID.names)
   }
 
+  # check whether N to p ratio is not too large, else MCD flags too many outliers
+  # See #672: This does seem to be a function of the N/p (N = sample size; p =
+  # number of parameters) ratio. When it is larger than 10, the % of outliers
+  # flagged is okay (in well behaved data). This makes sense: the MCD looks at
+  # the cov matrix of subsamples of the data - with high dimensional data, small
+  # samples sizes will give highly variable cov matrices, as so the "smallest"
+  # one will probably miss-represent the data.
+
+  if ((nrow(x) / ncol(x)) <= 10 && isTRUE(verbose)) {
+    insight::format_warning(
+      "The sample size is too small in your data, relative to the number of variables, for MCD to be reliable.",
+      "You may try to increase the `percentage_central` argument (must be between 0 and 1), or choose another method."
+    )
+  }
+
   insight::check_if_installed("MASS")
 
   # Compute
@@ -1750,7 +1836,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_ics <- function(x,
                                 threshold = 0.001,
                                 ID.names = NULL,
@@ -1828,10 +1913,10 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
 .check_outliers_optics <- function(x,
                                    threshold = NULL,
-                                   ID.names = NULL) {
+                                   ID.names = NULL,
+                                   xi = 0.05) {
   out <- data.frame(Row = seq_len(nrow(x)))
 
   if (!is.null(ID.names)) {
@@ -1842,7 +1927,7 @@ check_outliers.metabin <- check_outliers.metagen
 
   # Compute
   rez <- dbscan::optics(x, minPts = threshold)
-  rez <- dbscan::extractXi(rez, xi = 0.05) # TODO: find automatic way of setting xi
+  rez <- dbscan::extractXi(rez, xi = xi) # TODO: find automatic way of setting xi
 
   out$Distance_OPTICS <- rez$coredist
 
@@ -1893,7 +1978,6 @@ check_outliers.metabin <- check_outliers.metagen
 # }
 
 
-
 .check_outliers_lof <- function(x,
                                 threshold = 0.001,
                                 ID.names = NULL) {
@@ -1927,15 +2011,6 @@ check_outliers.metabin <- check_outliers.metagen
 }
 
 
-
-# influential observations data --------
-
-.influential_obs <- function(x, threshold = NULL) {
-  .safe(.diag_influential_obs(x, threshold = threshold))
-}
-
-
-
 # Non-supported model classes ---------------------------------------
 
 #' @export
@@ -1949,3 +2024,12 @@ check_outliers.lmrob <- check_outliers.glmmTMB
 
 #' @export
 check_outliers.glmrob <- check_outliers.glmmTMB
+
+#' @export
+check_outliers.rq <- check_outliers.glmmTMB
+
+#' @export
+check_outliers.rqs <- check_outliers.glmmTMB
+
+#' @export
+check_outliers.rqss <- check_outliers.glmmTMB
