@@ -11,6 +11,9 @@
 #'   of frequentist models (e.g., `lm`, `merMod`, `glmmTMB`, ...). For Bayesian
 #'   models, the model is passed to [`bayesplot::pp_check()`].
 #'
+#'   If `check_predictions()` doesn't work as expected, try setting
+#'   `verbose = TRUE` to get hints about possible problems.
+#'
 #' @param object A statistical model.
 #' @param iterations The number of draws to simulate/bootstrap.
 #' @param check_range Logical, if `TRUE`, includes a plot with the minimum
@@ -53,6 +56,9 @@
 #' package that imports **bayesplot** such as **rstanarm** or **brms**)
 #' is loaded, `pp_check()` is also available as an alias for `check_predictions()`.
 #'
+#' If `check_predictions()` doesn't work as expected, try setting `verbose = TRUE`
+#' to get hints about possible problems.
+#'
 #' @family functions to check model assumptions and and assess model quality
 #'
 #' @references
@@ -69,7 +75,7 @@
 #' - Gelman, A., Hill, J., and Vehtari, A. (2020). Regression and Other Stories.
 #'   Cambridge University Press.
 #'
-#' @examplesIf require("see")
+#' @examplesIf insight::check_if_installed("see", minimum_version = "0.9.1", quietly = TRUE)
 #' # linear model
 #' model <- lm(mpg ~ disp, data = mtcars)
 #' check_predictions(model)
@@ -101,6 +107,14 @@ check_predictions.default <- function(object,
                                       verbose = TRUE,
                                       ...) {
   .is_model_valid(object)
+  # check_predictions() can't handle exotic formula notation
+  if (verbose) {
+    insight::formula_ok(
+      object,
+      action = "error",
+      prefix_msg = "Posterior predictive checks failed due to an incompatible model formula." # nolint
+    )
+  }
 
   # retrieve model information
   minfo <- insight::model_info(object, verbose = FALSE)
@@ -249,7 +263,6 @@ check_predictions.lme <- function(object, ...) {
 }
 
 
-
 # pp-check functions -------------------------------------
 
 pp_check.lm <- function(object,
@@ -303,10 +316,18 @@ pp_check.lm <- function(object,
   pattern <- "^(scale|exp|expm1|log|log1p|log10|log2|sqrt)"
 
   # check for transformed response, and backtransform simulations
-  if (!is.null(resp_string) && grepl(paste0(pattern, "\\("), resp_string)) {
+  if (!is.null(resp_string) && length(resp_string) == 1 && grepl(paste0(pattern, "\\("), resp_string)) {
     out <- .backtransform_sims(out, resp_string)
   }
 
+  # sanity check - do we have a ratio or similar?
+  if (is.data.frame(response)) {
+    # get response data, evaluate formula
+    response <- eval(str2lang(insight::find_response(object)),
+      envir = insight::get_response(object)
+    )
+  }
+
   out$y <- response
 
   attr(out, "check_range") <- check_range
@@ -398,7 +419,6 @@ pp_check.glmmTMB   <-
 # styler: on
 
 
-
 #' @rawNamespace
 #' S3method(bayesplot::pp_check, lm)
 #' S3method(bayesplot::pp_check, glm)
@@ -415,26 +435,6 @@ pp_check.glmmTMB   <-
 #' S3method(bayesplot::pp_check, BFBayesFactor)
 
 
-
-# aliases --------------------------
-
-#' @rdname check_predictions
-#' @export
-posterior_predictive_check <- function(object, ...) {
-  .Deprecated("check_predictions()")
-  check_predictions(object, ...)
-}
-
-#' @rdname check_predictions
-#' @export
-check_posterior_predictions <- function(object, ...) {
-  .Deprecated("check_predictions()")
-  check_predictions(object, ...)
-}
-
-
-
-
 # methods -----------------------
 
 
@@ -510,7 +510,7 @@ plot.performance_pp_check <- function(x, ...) {
     if (is.null(plus_minus)) {
       plus_minus <- .safe(eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\1", resp_string))))
     }
-    if (is.null(plus_minus)) {
+    if (is.null(plus_minus) || !is.numeric(plus_minus)) {
       sims[] <- lapply(sims, exp)
     } else {
       sims[] <- lapply(sims, function(i) exp(i) - plus_minus)
