@@ -40,30 +40,25 @@
 #'
 #'   - **PCP**: percentage of correct predictions, see [performance_pcp()].
 #'
-#' @examples
-#' \dontrun{
-#' if (require("rstanarm") && require("rstantools")) {
-#'   model <- stan_glm(mpg ~ wt + cyl, data = mtcars, chains = 1, iter = 500, refresh = 0)
-#'   model_performance(model)
+#' @examplesIf require("rstanarm") && require("rstantools")
+#' \donttest{
+#' model <- suppressWarnings(rstanarm::stan_glm(
+#'   mpg ~ wt + cyl,
+#'   data = mtcars,
+#'   chains = 1,
+#'   iter = 500,
+#'   refresh = 0
+#' ))
+#' model_performance(model)
 #'
-#'   model <- stan_glmer(
-#'     mpg ~ wt + cyl + (1 | gear),
-#'     data = mtcars,
-#'     chains = 1,
-#'     iter = 500,
-#'     refresh = 0
-#'   )
-#'   model_performance(model)
-#' }
-#'
-#' if (require("BayesFactor") && require("rstantools")) {
-#'   model <- generalTestBF(carb ~ am + mpg, mtcars)
-#'
-#'   model_performance(model)
-#'   model_performance(model[3])
-#'
-#'   model_performance(model, average = TRUE)
-#' }
+#' model <- suppressWarnings(rstanarm::stan_glmer(
+#'   mpg ~ wt + cyl + (1 | gear),
+#'   data = mtcars,
+#'   chains = 1,
+#'   iter = 500,
+#'   refresh = 0
+#' ))
+#' model_performance(model)
 #' }
 #' @seealso [r2_bayes]
 #' @references Gelman, A., Goodrich, B., Gabry, J., and Vehtari, A. (2018).
@@ -84,7 +79,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
     metrics <- c("LOOIC", "WAIC", "R2", "RMSE")
   }
 
-  # check for valid input
+
   metrics <- toupper(.check_bad_metrics(metrics, all_metrics, verbose))
 
   algorithm <- insight::find_algorithm(model)
@@ -142,10 +137,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
 
   # LOO-R2 ------------------
   if (("R2_ADJUSTED" %in% metrics || "R2_LOO" %in% metrics) && mi$is_linear) {
-    r2_adj <- tryCatch(
-      suppressWarnings(r2_loo(model, verbose = verbose)),
-      error = function(e) NULL
-    )
+    r2_adj <- .safe(suppressWarnings(r2_loo(model, verbose = verbose)))
     if (!is.null(r2_adj)) {
       # save attributes
       attri_r2$SE$R2_loo <- attributes(r2_adj)$SE$R2_loo
@@ -167,10 +159,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
 
   # ICC ------------------
   if ("ICC" %in% metrics) {
-    out$ICC <- tryCatch(
-      suppressWarnings(icc(model, verbose = verbose)$ICC_adjusted),
-      error = function(e) NULL
-    )
+    out$ICC <- .safe(suppressWarnings(icc(model, verbose = verbose)$ICC_adjusted))
   }
 
   # RMSE ------------------
@@ -180,47 +169,30 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
 
   # SIGMA ------------------
   if ("SIGMA" %in% metrics) {
-    out$Sigma <- tryCatch(
-      {
-        s <- .get_sigma(model, verbose = verbose)
-        if (insight::is_empty_object(s)) {
-          s <- NULL
-        }
-        s
-      },
-      error = function(e) {
-        NULL
+    out$Sigma <- .safe({
+      s <- .get_sigma(model, verbose = verbose)
+      if (insight::is_empty_object(s)) {
+        s <- NULL
       }
-    )
+      s
+    })
   }
 
   # LOGLOSS ------------------
   if (("LOGLOSS" %in% metrics) && mi$is_binomial) {
-    out$Log_loss <- tryCatch(
-      {
-        .logloss <- performance_logloss(model, verbose = verbose)
-        if (!is.na(.logloss)) {
-          .logloss
-        } else {
-          NULL
-        }
-      },
-      error = function(e) {
+    out$Log_loss <- .safe({
+      .logloss <- performance_logloss(model, verbose = verbose)
+      if (!is.na(.logloss)) {
+        .logloss
+      } else {
         NULL
       }
-    )
+    })
   }
 
   # SCORE ------------------
   if (("SCORE" %in% metrics) && (mi$is_binomial || mi$is_count)) {
-    .scoring_rules <- tryCatch(
-      {
-        performance_score(model, verbose = verbose)
-      },
-      error = function(e) {
-        NULL
-      }
-    )
+    .scoring_rules <- .safe(performance_score(model, verbose = verbose))
     if (!is.null(.scoring_rules)) {
       if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
       if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
@@ -229,7 +201,7 @@ model_performance.stanreg <- function(model, metrics = "all", verbose = TRUE, ..
 
   out <- as.data.frame(out)
   row.names(out) <- NULL
-  out <- out[sapply(out, function(i) !all(is.na(i)))]
+  out <- out[vapply(out, function(i) !all(is.na(i)), TRUE)]
 
   attributes(out) <- c(attributes(out), attri)
   class(out) <- c("performance_model", class(out))
@@ -254,21 +226,29 @@ model_performance.BFBayesFactor <- function(model,
                                             average = FALSE,
                                             prior_odds = NULL,
                                             ...) {
+  all_metrics <- c("R2", "SIGMA")
+
   if (all(metrics == "all")) {
-    metrics <- c("R2", "SIGMA")
+    metrics <- all_metrics
   }
 
+
+  metrics <- toupper(.check_bad_metrics(metrics, all_metrics, verbose))
+
+  # check for valid BFBayesFactor object
   mi <- insight::model_info(model, verbose = FALSE)
   if (!mi$is_linear || mi$is_correlation || mi$is_ttest || mi$is_binomial || mi$is_meta) {
-    insight::format_warning("Can produce ", paste0(metrics, collapse = " & "), " only for linear models.")
+    if (isTRUE(verbose)) {
+      insight::format_warning("This type of Bayes factor models is not supported.")
+    }
     return(NULL)
   }
 
   out <- list()
   attri <- list()
 
-  if ("R2" %in% c(metrics)) {
-    r2 <- r2_bayes(model, average = average, prior_odds = prior_odds)
+  if ("R2" %in% metrics) {
+    r2 <- r2_bayes(model, average = average, prior_odds = prior_odds, verbose = verbose)
     attri$r2_bayes <- attributes(r2) # save attributes
 
     # Format to df then to list
@@ -301,7 +281,6 @@ model_performance.BFBayesFactor <- function(model,
 }
 
 
-
 # helper -------------------
 
 
@@ -311,7 +290,9 @@ model_performance.BFBayesFactor <- function(model,
   }
 
   params <- insight::get_parameters(model, verbose = verbose)
-  if (!"sig2" %in% colnames(params)) stop("This is not a linear model.", call. = FALSE)
+  if (!"sig2" %in% colnames(params)) {
+    insight::format_error("This is not a linear model.")
+  }
   sqrt(params$sig2)
 }
 
