@@ -1,8 +1,21 @@
 #' @title Simple ROC curve
 #' @name performance_roc
 #'
-#' @description This function calculates a simple ROC curves of x/y coordinates
-#' based on response and predictions of a binomial model.
+#' @description
+#' This function calculates a simple ROC curves of x/y coordinates based on
+#' response and predictions of a binomial model.
+#'
+#' It returns the area under the curve (AUC) as a percentage, which corresponds
+#' to the probability that a randomly chosen observation of "condition 1" is
+#' correctly classified by the model as having a higher probability of being
+#' "condition 1" than a randomly chosen "condition 2" observation.
+#'
+#' Applying `as.data.frame()` to the output returns a data frame containing the
+#' following:
+#' - `Sensitivity` (that actually corresponds to `1 - Specificity`): It is the
+#'   False Positive Rate.
+#' - `Sensitivity`: It is the True Positive Rate, which is the proportion of
+#'   correctly classified "condition 1" observations.
 #'
 #' @param x A numeric vector, representing the outcome (0/1), or a model with
 #'   binomial outcome.
@@ -14,7 +27,8 @@
 #' @param ... One or more models with binomial outcome. In this case,
 #'   `new_data` is ignored.
 #'
-#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/performance.html)
+#' implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
 #' @return A data frame with three columns, the x/y-coordinate pairs for the ROC
 #'   curve (`Sensitivity` and `Specificity`), and a column with the
@@ -32,6 +46,7 @@
 #'
 #' model <- glm(y ~ Sepal.Length + Sepal.Width, data = train_data, family = "binomial")
 #' as.data.frame(performance_roc(model, new_data = test_data))
+#' as.numeric(performance_roc(model))
 #'
 #' roc <- performance_roc(model, new_data = test_data)
 #' area_under_curve(roc$Specificity, roc$Sensitivity)
@@ -75,7 +90,6 @@ performance_roc <- function(x, ..., predictions, new_data) {
 }
 
 
-
 # methods -----------------------------
 
 #' @export
@@ -108,12 +122,27 @@ print.performance_roc <- function(x, ...) {
 }
 
 
+#' @export
+as.double.performance_roc <- function(x, ...) {
+  if (length(unique(x$Model)) == 1) {
+    auc <- bayestestR::area_under_curve(x$Specificity, x$Sensitivity)
+  } else {
+    dat <- split(x, f = x$Model)
+
+    auc <- numeric(length(dat))
+    for (i in seq_along(dat)) {
+      auc[i] <- bayestestR::area_under_curve(dat[[i]]$Specificity, dat[[i]]$Sensitivity)
+    }
+  }
+  auc
+}
+
 
 # utilities ---------------------------
 
 .performance_roc_numeric <- function(x, predictions) {
   if (length(x) != length(predictions)) {
-    stop("'x' and ' predictions' must be of same length.", call. = FALSE)
+    insight::format_error("`x` and `predictions` must be of same length.")
   }
 
   x <- .recode_to_zero(x)
@@ -129,7 +158,6 @@ print.performance_roc <- function(x, ...) {
 }
 
 
-
 .performance_roc_model <- function(x, new_data, model_name = "Model 1") {
   predictions <- stats::predict(x, newdata = new_data, type = "response")
   if (is.null(new_data)) new_data <- insight::get_data(x, verbose = FALSE)
@@ -147,7 +175,6 @@ print.performance_roc <- function(x, ...) {
 }
 
 
-
 .performance_roc_models <- function(x, names) {
   l <- lapply(seq_along(x), function(i) {
     if (.valid_roc_models(x[[i]])) {
@@ -160,12 +187,11 @@ print.performance_roc <- function(x, ...) {
 }
 
 
-
 # add supported glm models here
 
 .valid_roc_models <- function(x) {
   if (inherits(x, "model_fit")) {
     x <- x$fit
   }
-  inherits(x, c("glm", "glmerMod", "logitor", "logitmfx", "probitmfx"))
+  inherits(x, c("glm", "glmerMod", "logitor", "logitmfx", "probitmfx", "glmmTMB"))
 }
