@@ -10,6 +10,9 @@
 #' (`TRUE`) or not (`FALSE`)?
 #' @param ci Confidence interval level, as scalar. If `NULL` (default), no
 #' confidence intervals for R2 are calculated.
+#' @param multivariate Logical. Should multiple R2 values be reported as
+#' separated by response (FALSE) or should a single R2 be reported as
+#' combined across responses computed by [`r2_mlm`] (TRUE).
 #' @param ... Arguments passed down to the related r2-methods.
 #' @inheritParams r2_nakagawa
 #'
@@ -23,14 +26,15 @@
 #'   - Mixed models: [Nakagawa's R2][r2_nakagawa]
 #'   - Bayesian models: [R2 bayes][r2_bayes]
 #'
-#' @note If there is no `r2()`-method defined for the given model class,
-#'   `r2()` tries to return a "generic" r-quared value, calculated as following:
-#'   `1-sum((y-y_hat)^2)/sum((y-y_bar)^2))`
+#' @note
+#' If there is no `r2()`-method defined for the given model class, `r2()` tries
+#' to return a "generic" r-quared value, calculated as following:
+#' `1-sum((y-y_hat)^2)/sum((y-y_bar)^2)`
 #'
-#' @seealso [`r2_bayes()`], [`r2_coxsnell()`], [`r2_kullback()`],
-#'   [`r2_loo()`], [`r2_mcfadden()`], [`r2_nagelkerke()`],
-#'   [`r2_nakagawa()`], [`r2_tjur()`], [`r2_xu()`] and
-#'   [`r2_zeroinflated()`].
+#' @seealso
+#' [`r2_bayes()`], [`r2_coxsnell()`], [`r2_kullback()`], [`r2_loo()`],
+#' [`r2_mcfadden()`], [`r2_nagelkerke()`], [`r2_nakagawa()`], [`r2_tjur()`],
+#' [`r2_xu()`], [`r2_zeroinflated()`], and [`r2_mlm()`].
 #'
 #' @examplesIf require("lme4")
 #' # Pseudo r-quared for GLM
@@ -244,24 +248,28 @@ r2.aov <- function(model, ci = NULL, ...) {
   structure(class = "r2_generic", out)
 }
 
-
+#' @rdname r2
 #' @export
-r2.mlm <- function(model, ...) {
-  model_summary <- summary(model)
+r2.mlm <- function(model, multivariate = TRUE, ...) {
+  if (multivariate) {
+    out <- r2_mlm(model)
+  } else {
+    model_summary <- summary(model)
 
-  out <- lapply(names(model_summary), function(i) {
-    tmp <- list(
-      R2 = model_summary[[i]]$r.squared,
-      R2_adjusted = model_summary[[i]]$adj.r.squared,
-      Response = sub("Response ", "", i, fixed = TRUE)
-    )
-    names(tmp$R2) <- "R2"
-    names(tmp$R2_adjusted) <- "adjusted R2"
-    names(tmp$Response) <- "Response"
-    tmp
-  })
+    out <- lapply(names(model_summary), function(i) {
+      tmp <- list(
+        R2 = model_summary[[i]]$r.squared,
+        R2_adjusted = model_summary[[i]]$adj.r.squared,
+        Response = sub("Response ", "", i, fixed = TRUE)
+      )
+      names(tmp$R2) <- "R2"
+      names(tmp$R2_adjusted) <- "adjusted R2"
+      names(tmp$Response) <- "Response"
+      tmp
+    })
 
-  names(out) <- names(model_summary)
+    names(out) <- names(model_summary)
+  }
 
   attr(out, "model_type") <- "Multivariate Linear"
   structure(class = "r2_mlm", out)
@@ -291,6 +299,12 @@ r2.glm <- function(model, ci = NULL, verbose = TRUE, ...) {
       insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     out <- NULL
+  } else if (info$is_orderedbeta) {
+    # ordered-beta-regression
+    out <- r2_ferrari(model, correct_bounds = TRUE)
+  } else if (info$is_beta) {
+    # beta-regression
+    out <- r2_ferrari(model)
   } else {
     out <- list(R2_Nagelkerke = r2_nagelkerke(model, ...))
     names(out$R2_Nagelkerke) <- "Nagelkerke's R2"
@@ -313,7 +327,6 @@ r2.nestedLogit <- function(model, ci = NULL, verbose = TRUE, ...) {
 }
 
 
-
 # mfx models ---------------------
 
 
@@ -350,8 +363,6 @@ r2.betaor <- r2.logitmfx
 r2.model_fit <- r2.logitmfx
 
 
-
-
 # Cox & Snell R2 ---------------------
 
 
@@ -370,8 +381,6 @@ r2.crch <- r2.BBreg
 r2.bayesx <- r2.BBreg
 
 
-
-
 # Nagelkerke R2 ----------------------
 
 
@@ -427,9 +436,6 @@ r2.mblogit <- function(model, ...) {
 }
 
 
-
-
-
 # McFadden ----------------------
 
 
@@ -444,8 +450,6 @@ r2.multinom <- function(model, ...) {
 r2.mlogit <- r2.multinom
 
 
-
-
 # Zeroinflated R2 ------------------
 
 
@@ -502,6 +506,7 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
     }
     # calculate r2 for non-mixed glmmTMB models here -------------------------
     info <- insight::model_info(model, verbose = FALSE)
+    matrix_response <- grepl("cbind", insight::find_response(model), fixed = TRUE)
 
     if (info$is_linear) {
       # for linear models, use the manual calculation
@@ -512,6 +517,17 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
       attr(out, "model_type") <- "Logistic"
       names(out$R2_Tjur) <- "Tjur's R2"
       class(out) <- c("r2_pseudo", class(out))
+    } else if (info$is_betabinomial) {
+      # currently, beta-binomial models without proportion response are not supported
+      if (matrix_response) {
+        if (verbose) {
+          insight::format_warning("Can't calculate accurate R2 for beta-binomial models with matrix-response formulation.")
+        }
+        out <- NULL
+      } else {
+        # betabinomial default to mcfadden, see pscl:::pR2Work
+        out <- r2_mcfadden(model)
+      }
     } else if (info$is_binomial && !info$is_bernoulli) {
       # currently, non-bernoulli binomial models are not supported
       if (verbose) {
@@ -527,8 +543,20 @@ r2.glmmTMB <- function(model, ci = NULL, tolerance = 1e-5, verbose = TRUE, ...)
     } else if (info$is_zero_inflated) {
       # zero-inflated models use the default method
       out <- r2_zeroinflated(model)
+    } else if (info$is_orderedbeta) {
+      # ordered-beta-regression
+      out <- r2_ferrari(model, correct_bounds = TRUE)
+    } else if (info$is_beta) {
+      # beta-regression
+      out <- r2_ferrari(model)
     } else {
-      insight::format_error("`r2()` does not support models of class `glmmTMB` without random effects and this link-function.") # nolint
+      insight::format_error(paste0(
+        "`r2()` does not support models of class `glmmTMB` without random effects and from ",
+        info$family,
+        "-family with ",
+        info$link_function,
+        "-link-function."
+      ))
     }
   }
   out
@@ -560,7 +588,6 @@ r2.wbm <- function(model, tolerance = 1e-5, ...) {
 }
 
 
-
 #' @export
 r2.sem <- function(model, ...) {
   r2_conditional <- model$r2c
@@ -579,7 +606,6 @@ r2.sem <- function(model, ...) {
 }
 
 
-
 # Bayes R2 ------------------------
 
 
@@ -638,7 +664,6 @@ r2.rma <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.feis <- function(model, ...) {
   out <- list(
@@ -651,7 +676,6 @@ r2.feis <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.fixest <- function(model, ...) {
   insight::check_if_installed("fixest")
@@ -682,12 +706,18 @@ r2.fixest <- function(model, ...) {
   structure(class = "r2_generic", out)
 }
 
+
 #' @export
 r2.fixest_multi <- function(model, ...) {
   lapply(model, r2.fixest)
 }
 
 
+#' @export
+r2.oohbchoice <- function(model, ...) {
+  NULL
+}
+
 
 #' @export
 r2.felm <- function(model, ...) {
@@ -702,8 +732,6 @@ r2.felm <- function(model, ...) {
 }
 
 
-
-
 #' @export
 r2.iv_robust <- function(model, ...) {
   out <- list(
@@ -716,7 +744,6 @@ r2.iv_robust <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.ivreg <- function(model, ...) {
   model_summary <- summary(model)
@@ -730,7 +757,6 @@ r2.ivreg <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.bigglm <- function(model, ...) {
   out <- list(R2_CoxSnell = summary(model)$rsq)
@@ -740,7 +766,6 @@ r2.bigglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.biglm <- function(model, ...) {
   df.int <- as.numeric(insight::has_intercept(model))
@@ -762,7 +787,6 @@ r2.biglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.lmrob <- function(model, ...) {
   model_summary <- summary(model)
@@ -779,7 +803,6 @@ r2.lmrob <- function(model, ...) {
 r2.complmrob <- r2.lmrob
 
 
-
 #' @export
 r2.mmclogit <- function(model, ...) {
   list(R2 = NA)
@@ -796,7 +819,6 @@ r2.Arima <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.plm <- function(model, ...) {
   model_summary <- summary(model)
@@ -810,7 +832,6 @@ r2.plm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.selection <- function(model, ...) {
   model_summary <- summary(model)
@@ -827,7 +848,6 @@ r2.selection <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.svyglm <- function(model, ...) {
   rsq <- (model$null.deviance - model$deviance) / model$null.deviance
@@ -843,7 +863,6 @@ r2.svyglm <- function(model, ...) {
 }
 
 
-
 #' @export
 r2.vglm <- function(model, ...) {
   out <- list(R2_McKelvey = r2_mckelvey(model))
@@ -856,7 +875,6 @@ r2.vglm <- function(model, ...) {
 r2.vgam <- r2.vglm
 
 
-
 #' @export
 r2.DirichletRegModel <- function(model, ...) {
   out <- list(R2_Nagelkerke = r2_nagelkerke(model))
@@ -866,9 +884,6 @@ r2.DirichletRegModel <- function(model, ...) {
 }
 
 
-
-
-
 # helper -------------------
 
 .check_r2_ci_args <- function(ci = NULL, ci_method = "bootstrap", valid_ci_method = NULL, verbose = TRUE) {
