@@ -8,7 +8,6 @@
 #' @return The R2 value.
 #'
 #' @details
-#'
 #' Efron's R2 is calculated by taking the sum of the squared model residuals,
 #' divided by the total variability in the dependent variable. This R2 equals
 #' the squared correlation between the predicted values and actual values,
@@ -16,9 +15,9 @@
 #' generally comparable to those of OLS.
 #'
 #' @references
-#' \itemize{
-#'   \item Efron, B. (1978). Regression and ANOVA with zero-one data: Measures of residual variation. Journal of the American Statistical Association, 73, 113-121.
-#' }
+#' Efron, B. (1978). Regression and ANOVA with zero-one data: Measures of
+#' residual variation. Journal of the American Statistical Association, 73,
+#' 113-121.
 #'
 #' @examples
 #' ## Dobson (1990) Page 93: Randomized Controlled Trial:
@@ -42,6 +41,6 @@ r2_efron.default <- function(model) {
 
 .r2_efron <- function(model) {
   y_hat <- stats::predict(model, type = "response")
-  y <- .factor_to_numeric(insight::get_response(model, verbose = FALSE), lowest = 0)
+  y <- datawizard::to_numeric(insight::get_response(model, verbose = FALSE), dummy_factors = FALSE, preserve_levels = TRUE, lowest = 0)
   (1 - (sum((y - y_hat)^2)) / (sum((y - mean(y))^2)))
 }
