@@ -7,6 +7,7 @@
 #' @param model A generalized linear model.
 #' @param adjust Logical, if `TRUE` (the default), the adjusted R2 value is
 #'   returned.
+#' @param ... Additional arguments. Currently not used.
 #'
 #' @return A named vector with the R2 value.
 #'
@@ -19,7 +20,13 @@
 #' 77: 329-342.
 #'
 #' @export
-r2_kullback <- function(model, adjust = TRUE) {
+r2_kullback <- function(model, ...) {
+  UseMethod("r2_kullback")
+}
+
+#' @rdname r2_kullback
+#' @export
+r2_kullback.glm <- function(model, adjust = TRUE, ...) {
   if (adjust) {
     adj <- model$df.null / model$df.residual
   } else {
@@ -31,3 +38,8 @@ r2_kullback <- function(model, adjust = TRUE) {
   names(klr2) <- "Kullback-Leibler R2"
   klr2
 }
+
+#' @export
+r2_kullback.default <- function(model, ...) {
+  insight::format_error("This function only works for objects of class `glm`.")
+}
