@@ -21,6 +21,7 @@
 #'   `test_bf()` describes models by their formulas, which can lead to
 #'   overly long lines in the output. `text_length` fixes the length of
 #'   lines to a specified limit.
+#' @param verbose Toggle warning and messages.
 #'
 #' @return A data frame containing the relevant indices.
 #'
@@ -31,11 +32,11 @@
 #' ## Nested vs. Non-nested Models
 #' Model's "nesting" is an important concept of models comparison. Indeed, many
 #' tests only make sense when the models are *"nested",* i.e., when their
-#' predictors are nested. This means that all the predictors of a model are
-#' contained within the predictors of a larger model (sometimes referred to as
-#' the encompassing model). For instance, `model1 (y ~ x1 + x2)` is
-#' "nested" within `model2 (y ~ x1 + x2 + x3)`. Usually, people have a list
-#' of nested models, for instance `m1 (y ~ 1)`, `m2 (y ~ x1)`,
+#' predictors are nested. This means that all the *fixed effects* predictors of
+#' a model are contained within the *fixed effects* predictors of a larger model
+#' (sometimes referred to as the encompassing model). For instance,
+#' `model1 (y ~ x1 + x2)` is "nested" within `model2 (y ~ x1 + x2 + x3)`. Usually,
+#' people have a list of nested models, for instance `m1 (y ~ 1)`, `m2 (y ~ x1)`,
 #' `m3 (y ~ x1 + x2)`, `m4 (y ~ x1 + x2 + x3)`, and it is conventional
 #' that they are "ordered" from the smallest to largest, but it is up to the
 #' user to reverse the order from largest to smallest. The test then shows
@@ -224,40 +225,38 @@
 #'    structural equation models. Psychological Methods, 21, 151-163.
 #'
 #' @export
-test_performance <- function(..., reference = 1) {
+test_performance <- function(..., reference = 1, verbose = TRUE) {
   UseMethod("test_performance")
 }
 
 
-
 # default --------------------------------
 
 #' @export
-test_performance.default <- function(..., reference = 1, include_formula = FALSE) {
+test_performance.default <- function(..., reference = 1, include_formula = FALSE, verbose = TRUE) {
   # Attribute class to list and get names from the global environment
-  objects <- insight::ellipsis_info(..., only_models = TRUE)
+  my_objects <- insight::ellipsis_info(..., only_models = TRUE)
 
-  # Sanity checks (will throw error if non-valid objects)
-  .test_performance_checks(objects)
+  # validation checks (will throw error if non-valid objects)
+  my_objects <- .test_performance_checks(my_objects, verbose = verbose)
 
   # ensure proper object names
-  objects <- .check_objectnames(objects, sapply(match.call(expand.dots = FALSE)$`...`, as.character))
+  my_objects <- .check_objectnames(my_objects, sapply(match.call(expand.dots = FALSE)[["..."]], as.character))
 
   # If a suitable class is found, run the more specific method on it
-  if (inherits(objects, c("ListNestedRegressions", "ListNonNestedRegressions", "ListLavaan"))) {
-    test_performance(objects, reference = reference, include_formula = include_formula)
+  if (inherits(my_objects, c("ListNestedRegressions", "ListNonNestedRegressions", "ListLavaan"))) {
+    test_performance(my_objects, reference = reference, include_formula = include_formula)
   } else {
     insight::format_error("The models cannot be compared for some reason :/")
   }
 }
 
 
-
 # methods ------------------------------
 
 #' @export
 plot.test_performance <- function(x, ...) {
-  insight::format_warning(
+  insight::format_alert(
     "There is currently no `plot()` method for test-functions.",
     "Please use `plot(compare_perfomance())` for some visual representations of your model comparisons."
   )
@@ -267,11 +266,11 @@ plot.test_performance <- function(x, ...) {
 #' @export
 format.test_performance <- function(x, digits = 2, ...) {
   # Format cols and names
-  out <- insight::format_table(x, digits = digits, ...)
+  out <- insight::format_table(x, digits = digits, exact = FALSE, ...)
 
   if (isTRUE(attributes(x)$is_nested)) {
     footer <- paste0(
-      "Models were detected as nested and are compared in sequential order.\n"
+      "Models were detected as nested (in terms of fixed parameters) and are compared in sequential order.\n"
     )
   } else {
     footer <- paste0(
@@ -314,7 +313,6 @@ display.test_performance <- function(object, format = "markdown", digits = 2, ..
 }
 
 
-
 # other classes -----------------------------------
 
 #' @export
@@ -405,7 +403,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
 # TESTS IMPLEMENTED IN OTHER PACKAGES
 
 # # Non-nested
@@ -415,15 +412,14 @@ test_performance.ListNonNestedRegressions <- function(objects,
 # nonnest2::icci(m2, m3)
 
 
-
 # Helpers -----------------------------------------------------------------
 
 
 .test_performance_init <- function(objects, include_formula = FALSE) {
-  names <- insight::model_name(objects, include_formula = include_formula)
+  model_names <- insight::model_name(objects, include_formula = include_formula)
   out <- data.frame(
     Name = names(objects),
-    Model = names,
+    Model = model_names,
     stringsAsFactors = FALSE
   )
   row.names(out) <- NULL
@@ -431,16 +427,27 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
-.test_performance_checks <- function(objects, multiple = TRUE, same_response = TRUE) {
+.test_performance_checks <- function(objects, multiple = TRUE, same_response = TRUE, verbose = TRUE) {
   # TODO: we could actually generate a baseline model 'y ~ 1' whenever a single model is passed
   if (multiple && insight::is_model(objects)) {
-    insight::format_error("At least two models are required to test them.")
+    null_model <- .safe(insight::null_model(objects, verbose = FALSE))
+    if (!is.null(null_model) && insight::is_model(null_model)) {
+      objects <- insight::ellipsis_info(list(null_model, objects))
+      names(objects) <- c("Null model", "Full model")
+      if (verbose) {
+        insight::format_alert(
+          "Only one model was provided, however, at least two are required for comparison.",
+          "Fitting a null-model as reference now."
+        )
+      }
+    } else {
+      insight::format_error("At least two models are required to test them.")
+    }
   }
 
   if (same_response && !inherits(objects, "ListLavaan") && isFALSE(attributes(objects)$same_response)) {
     insight::format_error(
-      "The models' dependent variables don't have the same data, which is a prerequisite to compare them. Probably the proportion of missing data differs between models."
+      "The models' dependent variables don't have the same data, which is a prerequisite to compare them. Probably the proportion of missing data differs between models." # nolint
     )
   }
 
@@ -459,7 +466,6 @@ test_performance.ListNonNestedRegressions <- function(objects,
 }
 
 
-
 .check_objectnames <- function(objects, dot_names) {
   # Replace with names from the global environment, if these are not yet properly set
   object_names <- insight::compact_character(names(objects))
